@@ -1,6 +1,6 @@
 package Catmandu::Store::Resolver;
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 
 use Catmandu::Sane;
 
@@ -28,12 +28,22 @@ sub _build_client {
 
 =head1 NAME
 
+=for html <a href="https://travis-ci.org/PACKED-vzw/Catmandu-Store-Resolver"><img src="https://travis-ci.org/PACKED-vzw/Catmandu-Store-Resolver.svg?branch=master"></a>
+
 Catmandu::Store::Resolver - Store/retrieve items from the Resolver
 
 =head1 SYNOPSIS
 
 A module that can be used to retrieve or store PIDS for records in the L<Resolver|https://github.com/PACKED-vzw/resolver>.
 
+    lookup_in_store(
+        objectNumber,
+        Resolver,
+        username: username,
+        password: password,
+        url: http://www.resolver.be
+    )
+
 =head1 DESCRIPTION
 
 Configure the L<Resolver|https://github.com/PACKED-vzw/resolver> as a L<store|http://librecat.org/Catmandu/#stores> for L<Catmandu|http://librecat.org/>.
@@ -42,6 +52,19 @@ Museum objects and records require a PID to be uniquely identifiable. The Resolv
 
 Data is returned as JSON.
 
+    {
+        "data": {
+            "documents": [],
+            "domain": "",
+            "id": "",
+            "persystentURIs": [
+                dataPid
+            ],
+            "title": "",
+            "type": ""
+        }
+    }
+
 =head1 CONFIGURATION
 
 The Resolver API requires a username and password. These must be provided.
@@ -72,19 +95,11 @@ L<Catmandu>
 
 =head1 AUTHORS
 
-=over
-
-=item Pieter De Praetere, C<< pieter at packed.be >>
-
-=back
+Pieter De Praetere, C<< pieter at packed.be >>
 
 =head1 CONTRIBUTORS
 
-=over
-
-=item Pieter De Praetere, C<< pieter at packed.be >>
-
-=back
+Pieter De Praetere, C<< pieter at packed.be >>
 
 =head1 COPYRIGHT AND LICENSE
 
